@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -96,6 +96,7 @@ class Teacher(abstract.MelodicIntervalTeacher):
         self.m_tonika = None
 
 class Gui(abstract.IntervalGui):
+    lesson_heading = _("Identify the interval")
     def __init__(self, teacher):
         abstract.IntervalGui.__init__(self, teacher)
         self.g_test_stat_dlg = None
@@ -110,6 +111,7 @@ class Gui(abstract.IntervalGui):
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------
         self._create_select_inputwidget_gui()
+        self.add_lock_to_key_gui()
         self.config_box.show_all()
         ##############
         # statistics #
@@ -195,12 +197,6 @@ class Gui(abstract.IntervalGui):
         md = d / abs(d)
         if self.g_input.know_directions():
             md = 1
-        # If the user answers with keyboard shortcuts, then their answer does
-        # not say if the interval goes up or down. So we assumes the user
-        # got the direction correct.
-        if mouse_button == self.keyboard_accel:
-            if self.m_answer[-1] > 0 and d < 0:
-                self.m_answer[-1] = -self.m_answer[-1]
         if not self.msg:
             self.msg = utils.int_to_intervalname(interval * md, 1, 1) + "+ ..."
         else:
@@ -261,15 +257,13 @@ class Gui(abstract.IntervalGui):
     def on_start_practise(self):
         self.m_t.start_practise()
         super(Gui, self).on_start_practise()
-        if self.m_t.m_P.header.lesson_heading:
-            self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
-        else:
-            self.set_lesson_heading(_("Identify the interval"))
         if self.m_t.m_custom_mode:
             self.g_mici.show()
+            self.g_lock_to_key_hbox.show()
         else:
             self.m_t.m_statistics.reset_session()
             self.g_mici.hide()
+            self.g_lock_to_key_hbox.hide()
         self.g_statview.g_heading.set_text("%s - %s" % (_("Melodic interval"), self.m_t.m_P.header.title))
         self.std_buttons_start_practise()
         if solfege.app.m_test_mode:
